@@ -198,6 +198,9 @@ class Inductor(Element):
         branches: Mapping,
         freq: float = 0,
     ) -> None:
+        if freq == 0:
+            return
+
         if self.branch:
             self._stamp_with_current(freq, equation, nodes, branches)
         else:
